@@ -18,23 +18,9 @@
 
 #include "unicase/caseprop.h"
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
-#define ASSERT(expr) \
-  do									     \
-    {									     \
-      if (!(expr))							     \
-        {								     \
-          fprintf (stderr, "%s:%d: assertion failed for c = 0x%04X\n",	     \
-		   __FILE__, __LINE__, c);				     \
-          fflush (stderr);						     \
-          abort ();							     \
-        }								     \
-    }									     \
-  while (0)
-#define SIZEOF(a) (sizeof(a) / sizeof(a[0]))
+#include "macros.h"
 
 /* Interval of Unicode characters.  */
 typedef struct { ucs4_t start; ucs4_t end; } interval_t;
