@@ -22,23 +22,9 @@
 #include "unicase.h"
 
 #include <locale.h>
-#include <stdio.h>
-#include <stdlib.h>
 
 #include "uninorm.h"
-
-#define SIZEOF(array) (sizeof (array) / sizeof (array[0]))
-#define ASSERT(expr) \
-  do									     \
-    {									     \
-      if (!(expr))							     \
-        {								     \
-          fprintf (stderr, "%s:%d: assertion failed\n", __FILE__, __LINE__); \
-          fflush (stderr);						     \
-          abort ();							     \
-        }								     \
-    }									     \
-  while (0)
+#include "macros.h"
 
 #define UNIT char
 #include "test-casecmp.h"
