@@ -1,5 +1,5 @@
 /* Test of line breaking of UTF-8 strings.
-   Copyright (C) 2008 Free Software Foundation, Inc.
+   Copyright (C) 2008-2009 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,21 +20,9 @@
 
 #include "unilbrk.h"
 
-#include <stdio.h>
 #include <stdlib.h>
 
-#define SIZEOF(array) (sizeof (array) / sizeof (array[0]))
-#define ASSERT(expr) \
-  do									     \
-    {									     \
-      if (!(expr))							     \
-        {								     \
-          fprintf (stderr, "%s:%d: assertion failed\n", __FILE__, __LINE__); \
-          fflush (stderr);						     \
-          abort ();							     \
-        }								     \
-    }									     \
-  while (0)
+#include "macros.h"
 
 int
 main ()
@@ -53,16 +41,16 @@ main ()
 
       u8_possible_linebreaks (input, SIZEOF (input), "GB18030", p);
       for (i = 0; i < 91; i++)
-	{
-	  ASSERT (p[i] == (i == 90 ? UC_BREAK_MANDATORY :
-			   i == 7
-			   || i == 13 || i == 39
-			   || i == 41 || i == 43 || i == 44 || i == 50
-			   || i == 61 || i == 67
-			   || i == 70 || i == 73 || i == 77 || i == 80
-			   || i == 84 || i == 87 ? UC_BREAK_POSSIBLE :
-			   UC_BREAK_PROHIBITED));
-	}
+        {
+          ASSERT (p[i] == (i == 90 ? UC_BREAK_MANDATORY :
+                           i == 7
+                           || i == 13 || i == 39
+                           || i == 41 || i == 43 || i == 44 || i == 50
+                           || i == 61 || i == 67
+                           || i == 70 || i == 73 || i == 77 || i == 80
+                           || i == 84 || i == 87 ? UC_BREAK_POSSIBLE :
+                           UC_BREAK_PROHIBITED));
+        }
       free (p);
     }
 
@@ -72,16 +60,16 @@ main ()
 
       u8_possible_linebreaks (input, SIZEOF (input), "GB2312", p);
       for (i = 0; i < 91; i++)
-	{
-	  ASSERT (p[i] == (i == 90 ? UC_BREAK_MANDATORY :
-			   i == 7
-			   || i == 13 || i == 39
-			   || i == 41 || i == 43 || i == 44 || i == 50
-			   || i == 52 || i == 61 || i == 67
-			   || i == 70 || i == 73 || i == 77 || i == 80
-			   || i == 84 || i == 87 ? UC_BREAK_POSSIBLE :
-			   UC_BREAK_PROHIBITED));
-	}
+        {
+          ASSERT (p[i] == (i == 90 ? UC_BREAK_MANDATORY :
+                           i == 7
+                           || i == 13 || i == 39
+                           || i == 41 || i == 43 || i == 44 || i == 50
+                           || i == 52 || i == 61 || i == 67
+                           || i == 70 || i == 73 || i == 77 || i == 80
+                           || i == 84 || i == 87 ? UC_BREAK_POSSIBLE :
+                           UC_BREAK_PROHIBITED));
+        }
       free (p);
     }
   }
