@@ -1,5 +1,5 @@
 /* Test of line breaking of strings.
-   Copyright (C) 2008 Free Software Foundation, Inc.
+   Copyright (C) 2008-2009 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,21 +20,9 @@
 
 #include "unilbrk.h"
 
-#include <stdio.h>
 #include <stdlib.h>
 
-#define SIZEOF(array) (sizeof (array) / sizeof (array[0]))
-#define ASSERT(expr) \
-  do									     \
-    {									     \
-      if (!(expr))							     \
-        {								     \
-          fprintf (stderr, "%s:%d: assertion failed\n", __FILE__, __LINE__); \
-          fflush (stderr);						     \
-          abort ();							     \
-        }								     \
-    }									     \
-  while (0)
+#include "macros.h"
 
 int
 main ()
@@ -53,9 +41,9 @@ main ()
     ulc_width_linebreaks (input, SIZEOF (input), 12, 0, 0, NULL, "ISO-8859-1", p);
     for (i = 0; i < 36; i++)
       {
-	ASSERT (p[i] == (i == 35 ? UC_BREAK_MANDATORY :
-			 i == 11 || i == 21 || i == 31 ? UC_BREAK_POSSIBLE :
-			 UC_BREAK_PROHIBITED));
+        ASSERT (p[i] == (i == 35 ? UC_BREAK_MANDATORY :
+                         i == 11 || i == 21 || i == 31 ? UC_BREAK_POSSIBLE :
+                         UC_BREAK_PROHIBITED));
       }
     free (p);
   }
