@@ -1,5 +1,5 @@
 /* Test of u16_vasnprintf() function in an UTF-8 locale.
-   Copyright (C) 2007-2008 Free Software Foundation, Inc.
+   Copyright (C) 2007-2009 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,25 +22,12 @@
 
 #include <locale.h>
 #include <stdarg.h>
-#include <stdio.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
 
 #include "unistr.h"
-
-#define SIZEOF(array) (sizeof (array) / sizeof (array[0]))
-#define ASSERT(expr) \
-  do									     \
-    {									     \
-      if (!(expr))							     \
-        {								     \
-          fprintf (stderr, "%s:%d: assertion failed\n", __FILE__, __LINE__); \
-          fflush (stderr);						     \
-          abort ();							     \
-        }								     \
-    }									     \
-  while (0)
+#include "macros.h"
 
 static void
 test_function (uint16_t * (*my_asnprintf) (uint16_t *, size_t *, const char *, ...))
@@ -52,9 +39,9 @@ test_function (uint16_t * (*my_asnprintf) (uint16_t *, size_t *, const char *, .
     {
       size_t length;
       uint16_t *result =
-	my_asnprintf (NULL, &length, "%s %d", locale_string, 33, 44, 55);
+        my_asnprintf (NULL, &length, "%s %d", locale_string, 33, 44, 55);
       static const uint16_t expected[] =
-	{ 0x00c4, 'r', 'g', 'e', 'r', ' ', '3', '3', 0 };
+        { 0x00c4, 'r', 'g', 'e', 'r', ' ', '3', '3', 0 };
       ASSERT (result != NULL);
       ASSERT (u16_strcmp (result, expected) == 0);
       ASSERT (length == u16_strlen (result));
@@ -63,11 +50,11 @@ test_function (uint16_t * (*my_asnprintf) (uint16_t *, size_t *, const char *, .
     { /* Width.  */
       size_t length;
       uint16_t *result =
-	my_asnprintf (NULL, &length, "%10s %d", locale_string, 33, 44, 55);
+        my_asnprintf (NULL, &length, "%10s %d", locale_string, 33, 44, 55);
       static const uint16_t expected[] =
-	{ ' ', ' ', ' ', ' ', ' ', 0x00c4, 'r', 'g', 'e', 'r',
-	  ' ', '3', '3', 0
-	};
+        { ' ', ' ', ' ', ' ', ' ', 0x00c4, 'r', 'g', 'e', 'r',
+          ' ', '3', '3', 0
+        };
       ASSERT (result != NULL);
       ASSERT (u16_strcmp (result, expected) == 0);
       ASSERT (length == u16_strlen (result));
@@ -76,11 +63,11 @@ test_function (uint16_t * (*my_asnprintf) (uint16_t *, size_t *, const char *, .
     { /* FLAG_LEFT.  */
       size_t length;
       uint16_t *result =
-	my_asnprintf (NULL, &length, "%-10s %d", locale_string, 33, 44, 55);
+        my_asnprintf (NULL, &length, "%-10s %d", locale_string, 33, 44, 55);
       static const uint16_t expected[] =
-	{ 0x00c4, 'r', 'g', 'e', 'r', ' ', ' ', ' ', ' ', ' ',
-	  ' ', '3', '3', 0
-	};
+        { 0x00c4, 'r', 'g', 'e', 'r', ' ', ' ', ' ', ' ', ' ',
+          ' ', '3', '3', 0
+        };
       ASSERT (result != NULL);
       ASSERT (u16_strcmp (result, expected) == 0);
       ASSERT (length == u16_strlen (result));
@@ -89,11 +76,11 @@ test_function (uint16_t * (*my_asnprintf) (uint16_t *, size_t *, const char *, .
     { /* FLAG_ZERO: no effect.  */
       size_t length;
       uint16_t *result =
-	my_asnprintf (NULL, &length, "%010s %d", locale_string, 33, 44, 55);
+        my_asnprintf (NULL, &length, "%010s %d", locale_string, 33, 44, 55);
       static const uint16_t expected[] =
-	{ ' ', ' ', ' ', ' ', ' ', 0x00c4, 'r', 'g', 'e', 'r',
-	  ' ', '3', '3', 0
-	};
+        { ' ', ' ', ' ', ' ', ' ', 0x00c4, 'r', 'g', 'e', 'r',
+          ' ', '3', '3', 0
+        };
       ASSERT (result != NULL);
       ASSERT (u16_strcmp (result, expected) == 0);
       ASSERT (length == u16_strlen (result));
