@@ -20,21 +20,9 @@
 
 #include "uniwbrk.h"
 
-#include <stdio.h>
 #include <stdlib.h>
 
-#define SIZEOF(array) (sizeof (array) / sizeof (array[0]))
-#define ASSERT(expr) \
-  do									     \
-    {									     \
-      if (!(expr))							     \
-        {								     \
-          fprintf (stderr, "%s:%d: assertion failed\n", __FILE__, __LINE__); \
-          fflush (stderr);						     \
-          abort ();							     \
-        }								     \
-    }									     \
-  while (0)
+#include "macros.h"
 
 int
 main ()
@@ -46,11 +34,11 @@ main ()
     static const uint16_t input[61] =
       /* "Grüß Gott. Здравствуйте! x=(-b±sqrt(b²-4ac))/(2a)  日本語,中文,한글" */
       { 'G', 'r', 0x00FC, 0x00DF, ' ', 'G', 'o', 't', 't', '.', ' ',
-	0x0417, 0x0434, 0x0440, 0x0430, 0x0432, 0x0441, 0x0442, 0x0432, 0x0443,
-	0x0439, 0x0442, 0x0435, '!', ' ',
-	'x', '=', '(', '-', 'b', 0x00B1, 's', 'q', 'r', 't', '(', 'b', 0x00B2,
-	'-', '4', 'a', 'c', ')', ')', '/', '(', '2', 'a', ')', ' ', ' ',
-	0x65E5, 0x672C, 0x8A9E, ',', 0x4E2D, 0x6587, ',', 0xD55C, 0xAE00, '\n'
+        0x0417, 0x0434, 0x0440, 0x0430, 0x0432, 0x0441, 0x0442, 0x0432, 0x0443,
+        0x0439, 0x0442, 0x0435, '!', ' ',
+        'x', '=', '(', '-', 'b', 0x00B1, 's', 'q', 'r', 't', '(', 'b', 0x00B2,
+        '-', '4', 'a', 'c', ')', ')', '/', '(', '2', 'a', ')', ' ', ' ',
+        0x65E5, 0x672C, 0x8A9E, ',', 0x4E2D, 0x6587, ',', 0xD55C, 0xAE00, '\n'
       };
     char *p = (char *) malloc (SIZEOF (input));
     size_t i;
@@ -59,14 +47,14 @@ main ()
 
     for (i = 0; i < 61; i++)
       {
-	ASSERT (p[i] == ((i >= 4 && i <= 5)
-			 || (i >= 9 && i <= 11)
-			 || (i >= 23 && i <= 31)
-			 || (i >= 35 && i <= 39)
-			 || (i >= 42 && i <= 46)
-			 || (i >= 48 && i <= 58)
-			 || i == 60
-			 ? 1 : 0));
+        ASSERT (p[i] == ((i >= 4 && i <= 5)
+                         || (i >= 9 && i <= 11)
+                         || (i >= 23 && i <= 31)
+                         || (i >= 35 && i <= 39)
+                         || (i >= 42 && i <= 46)
+                         || (i >= 48 && i <= 58)
+                         || i == 60
+                         ? 1 : 0));
       }
     free (p);
   }
@@ -76,12 +64,12 @@ main ()
     static const uint16_t input[67] =
       /* "Grüß Gott. Здравствуйте! x=(-b±sqrt(b²-4ac))/(2a)  日本語,中文,한글" */
       { 'G', 'r', 0x0075, 0x0308, 0x00DF, ' ', 'G', 'o', 't', 't', '.', ' ',
-	0x0417, 0x0434, 0x0440, 0x0430, 0x0432, 0x0441, 0x0442, 0x0432, 0x0443,
-	0x0438, 0x0306, 0x0442, 0x0435, '!', ' ',
-	'x', '=', '(', '-', 'b', 0x00B1, 's', 'q', 'r', 't', '(', 'b', 0x00B2,
-	'-', '4', 'a', 'c', ')', ')', '/', '(', '2', 'a', ')', ' ', ' ',
-	0x65E5, 0x672C, 0x8A9E, ',', 0x4E2D, 0x6587, ',',
-	0x1112, 0x1161, 0x11AB, 0x1100, 0x1173, 0x11AF, '\n'
+        0x0417, 0x0434, 0x0440, 0x0430, 0x0432, 0x0441, 0x0442, 0x0432, 0x0443,
+        0x0438, 0x0306, 0x0442, 0x0435, '!', ' ',
+        'x', '=', '(', '-', 'b', 0x00B1, 's', 'q', 'r', 't', '(', 'b', 0x00B2,
+        '-', '4', 'a', 'c', ')', ')', '/', '(', '2', 'a', ')', ' ', ' ',
+        0x65E5, 0x672C, 0x8A9E, ',', 0x4E2D, 0x6587, ',',
+        0x1112, 0x1161, 0x11AB, 0x1100, 0x1173, 0x11AF, '\n'
       };
     char *p = (char *) malloc (SIZEOF (input));
     size_t i;
@@ -90,14 +78,14 @@ main ()
 
     for (i = 0; i < 67; i++)
       {
-	ASSERT (p[i] == ((i >= 5 && i <= 6)
-			 || (i >= 10 && i <= 12)
-			 || (i >= 25 && i <= 33)
-			 || (i >= 37 && i <= 41)
-			 || (i >= 44 && i <= 48)
-			 || (i >= 50 && i <= 60)
-			 || i == 66
-			 ? 1 : 0));
+        ASSERT (p[i] == ((i >= 5 && i <= 6)
+                         || (i >= 10 && i <= 12)
+                         || (i >= 25 && i <= 33)
+                         || (i >= 37 && i <= 41)
+                         || (i >= 44 && i <= 48)
+                         || (i >= 50 && i <= 60)
+                         || i == 66
+                         ? 1 : 0));
       }
     free (p);
   }
